@@ -21,8 +21,10 @@ avail_tmin <- paste0(
 avail_tdmean <- paste0("PRISM_tdmean_stable_4kmM3_2005", 11:12, "_bil")
 
 avail_vpdmin <- "PRISM_vpdmin_30yr_normal_4kmM4_annual_bil"
+avail_daily_normal <- "PRISM_ppt_30yr_normal_4kmD1_0301_bil"
 
-all_avail <- c(avail_tmin, avail_ppt, avail_tdmean, avail_vpdmin)
+all_avail <- c(avail_tmin, avail_ppt, avail_tdmean, avail_vpdmin, 
+               avail_daily_normal)
 
 for (ff in all_avail) {
   utils::unzip(
