@@ -18,7 +18,9 @@ test_that("pd_get_md() works", {
   expect_setequal(colnames(x), exp_cols)
   
   expect_s3_class(
-    x <- pd_get_md(prism_archive_subset("tdmean", "monthly", year = 2005, mon = 11:12)), 
+    x <- pd_get_md(
+      prism_archive_subset("tdmean", "monthly", year = 2005, mon = 11:12)
+    ), 
     "data.frame"
   )
   expect_identical(dim(x), c(2L, 8L))
@@ -34,7 +36,7 @@ test_that("pd_get_md() works", {
   expect_setequal(colnames(x), exp_cols)
   
   expect_s3_class(
-    y <- pd_get_md(prism_archive_subset("tmin", "daily", dates = "1981-01-01")), 
+    y <- pd_get_md(prism_archive_subset("tmin", "daily", dates = "1981-01-01")),
     "data.frame"
   )
   
@@ -48,4 +50,14 @@ test_that("pd_get_md() works", {
   )
   expect_identical(dim(x), c(1L, 8L))
   expect_setequal(colnames(x), exp_cols)
+  
+  # daily normal
+  expect_s3_class(
+    x <- pd_get_md(
+      prism_archive_subset("ppt", "daily normals", resolution = "4km", mon = 3)
+    ), 
+    "data.frame"
+  )
+  expect_identical(dim(x), c(1L, 8L))
+  expect_setequal(colnames(x), exp_cols)
 })
